@@ -12,7 +12,10 @@ from ..utils import gconfig
 from ..utils import md
 
 class EXP():
-    def __init__(self, workspace=None, exp_name=None, exp_description=None):
+    def __init__(self, workspace=None, exp_name=None, exp_description=None, check_git=True):
+        if check_git:
+           check_working_tree()
+
         if workspace is None:
             workspace = 'run'
         if exp_description is None:
@@ -29,8 +32,8 @@ class EXP():
         self._set_git_id()
         self._set_dir()
 
-    def add_info(self, key, value):
-        self.info[key] = value
+    def add_info(self, info_dict):
+        self.info.update(info_dict)
 
     def get_info(self, key):
         return self.info[key]
@@ -98,20 +101,22 @@ class EXP():
         if self.exp_seed is not None:
             md.add_title(results, 'Seed', level=5)
             md.add_text(results, str(self.exp_seed))
-
-        md.add_title(results, 'Metric', level=5)
-        for metric in self.metrics:
-            metric_text = metric.value_label+':   final: '+str(round(metric.value, metric.decimal))+', avg: '+str(round(metric.avg, metric.decimal))+', sum: '+str(round(metric.sum, metric.decimal))
-            md.add_text(results, metric_text)
+        
+        if self.metrics: 
+            md.add_title(results, 'Metric', level=5)
+            for metric in self.metrics:
+                metric_text = metric.value_label+':   final: '+str(round(metric.value, metric.decimal))+', avg: '+str(round(metric.avg, metric.decimal))+', sum: '+str(round(metric.sum, metric.decimal))
+                md.add_text(results, metric_text)
 
         for metric in self.metrics:
             if metric.draw:
                 md.add_image(results, metric.value_label, metric.file_path)
 
-        md.add_title(results, 'Info', level=5)
-        for (key, value) in self.info.items():
-            md.add_title(results, key, level=6)
-            md.add_text(results, str(value))
+        if self.info:
+            md.add_title(results, 'Info', level=5)
+            for (key, value) in self.info.items():
+                md.add_title(results, key, level=6)
+                md.add_text(results, str(value))
 
         md.add_title(results, 'Params', level=5)
         md.add_code(results, dict2jsonstr(self.params._param_dict))
